@@ -1,13 +1,11 @@
 # -*- encoding: UTF-8 -*-
 '''
-Created on 28 mars 2010
+Created on Apr 18, 2010
 
-@author: thierry
+@author: maemo
 '''
 
-
-
-CURRENT_VERSION = "0.2.2"  # this must be modified before any release
+CURRENT_VERSION = "0.3.0"  # this must be modified before any release
 
 def getInstance():
     return SINGLETON
@@ -46,4 +44,4 @@ class Version(object):
     
 SINGLETON = Version()  # object that track the revision of current applcation for issue tracking purpose
 
-getInstance().submitRevision("$Revision: 74 $")
+getInstance().submitRevision("$Revision: 96 $")
